@@ -6,10 +6,9 @@ field names & data types) using a Viterbi algorithm.
 (https://en.wikipedia.org/wiki/Viterbi_algorithm)
 
 On Linux, `sniff` also acts as a general mime type detector using the libmagic library,
-returning the detected mime type, file size and last modified date if the file is not
-a CSV. If --no-infer is enabled, it doesn't even bother to infer the CSV's schema. This
-makes it especially useful for accelerated CKAN harvesting and for checking stale/broken
-resource URLs.
+returning the detected mime type, file size and last modified date. If --no-infer is enabled,
+it doesn't even bother to infer the CSV's schema. This makes it especially useful for accelerated
+CKAN harvesting and for checking stale/broken resource URLs.
 
 On macOS and Windows however, `sniff` is only a CSV dialect detector and does not
 detect other file types. It can only sniff files with the "csv", "tsv", "tab" and
@@ -17,8 +16,11 @@ detect other file types. It can only sniff files with the "csv", "tsv", "tab" an
 "tsv.sz", etc.) extensions.
 
 NOTE: This command "sniffs" a CSV's schema by sampling the first n rows (default: 1000)
-of a file. Its inferences are sometimes wrong if the sample is not large enough 
-(use --sample to adjust) or the file is too small to infer a pattern. 
+of a file. Its inferences are sometimes wrong if the the file is too small to infer a pattern
+or if the CSV has unusual formatting - with atypical delimiters, quotes, etc.
+
+In such cases, selectively use the --sample, --delimiter and --quote options to improve
+the accuracy of the sniffed schema.
 
 If you want more robust, guaranteed schemata, use the "schema" or "stats" commands
 instead as they scan the entire file.
@@ -43,6 +45,7 @@ sniff arguments:
                              When --no-infer is enabled, sniff will not bother to infer the
                              CSV schema and just work as a general mime type detector -
                              returning the detected mime type, file size and last modified date.
+
                              When sniffing a local file, it will scan the file to detect the mime type.
                              When sniffing a URL, it will only download the first chunk of the file if 
                              the --quick option is enabled, otherwise it will download the entire file.
@@ -59,6 +62,15 @@ sniff options:
                              [default: 1000]
     --prefer-dmy             Prefer to parse dates in dmy format. Otherwise, use mdy format.
                              Ignored when --no-infer is enabled.
+    -d, --delimiter <arg>    The delimiter for reading CSV data.
+                             Specify this when the delimiter is known beforehand,
+                             as the delimiter inferencing algorithm can sometimes fail.
+                             Must be a single ascii character.
+    -q, --quote <arg>        The quote character for reading CSV data.
+                             Specify this when the quote character is known beforehand,
+                             as the quote char inferencing algorithm can sometimes fail.
+                             Must be a single ascii character - typically, double quote ("),
+                             single quote ('), or backtick (`).
     --json                   Return results in JSON format.
     --pretty-json            Return results in pretty JSON format.
     --save-urlsample <file>  Save the URL sample to a file.
@@ -85,11 +97,6 @@ sniff options:
 
 Common options:
     -h, --help               Display this message
-    -d, --delimiter <arg>    The field delimiter for reading CSV data.
-                             Specify this when the delimiter is known beforehand,
-                             as the delimiter guessing algorithm can sometimes be
-                               wrong if not enough delimiters are present in the sample.
-                             Must be a single ascii character.
     -p, --progressbar        Show progress bars. Only valid for URL input.
 "#;
 
@@ -129,6 +136,7 @@ struct Args {
     flag_save_urlsample: Option<String>,
     flag_pretty_json:    bool,
     flag_delimiter:      Option<Delimiter>,
+    flag_quote:          Option<char>,
     flag_progressbar:    bool,
     flag_timeout:        u16,
     flag_user_agent:     Option<String>,
@@ -283,7 +291,7 @@ const fn rowcount(
 ) -> (usize, bool) {
     let mut estimated = false;
     let rowcount = if count == usize::MAX {
-        // if the file is usize::MAX, it's a sentinel value for "Unknown" as the server
+        // if the count == usize::MAX, it's a sentinel value for "Unknown" as the server
         // didn't provide a Content-Length header, so we estimate the rowcount by
         // dividing the file_size by avg_rec_len
         estimated = true;
@@ -346,7 +354,7 @@ async fn get_file_to_sniff(args: &Args, tmpdir: &tempfile::TempDir) -> CliResult
                         // server did not return Last-Modified header
                         Err(_) => String::from("Unknown"),
                     },
-                    None => String::new(),
+                    None => String::from("Unknown"),
                 };
 
                 let total_size = match res.content_length() {
@@ -524,7 +532,7 @@ async fn get_file_to_sniff(args: &Args, tmpdir: &tempfile::TempDir) -> CliResult
                     // before we can sniff it
                     wtr_file_path =
                         util::decompress_snappy_file(&file.path().to_path_buf(), tmpdir)?;
-                } else if args.flag_quick && magic_flag {
+                } else if args.flag_quick && magic_flag && !csv_candidate {
                     // on linux, when --quiick is enabled, we short-circuit downloading by checking
                     // the file type from the first chunk. If the file is not a CSV,
                     // we just write the first chunk to a file and return
@@ -589,8 +597,8 @@ async fn get_file_to_sniff(args: &Args, tmpdir: &tempfile::TempDir) -> CliResult
                     retrieved_size: downloaded,
                     file_size: if magic_flag && total_size == usize::MAX {
                         // we're using magic and the server didn't give us content length
-                        // so send usize::MAX - 1 to indicate that we don't know the file size
-                        usize::MAX - 1
+                        // so send usize::MAX to indicate that we don't know the file size
+                        usize::MAX
                     } else if total_size == usize::MAX {
                         // the server didn't give us content length, so we just
                         // downloaded the entire file. downloaded variable
@@ -817,15 +825,12 @@ async fn sniff_main(mut args: Args) -> CliResult<()> {
         {
             cleanup_tempfile(sfile_info.tempfile_flag, tempfile_to_delete)?;
 
-            let size = if sfile_info.file_size >= usize::MAX - 1 {
+            let size = if sfile_info.file_size == usize::MAX {
                 "Unknown".to_string()
             } else {
                 sfile_info.file_size.to_string()
             };
-            let mut last_modified = sfile_info.last_modified;
-            if last_modified.is_empty() {
-                last_modified = "Unknown".to_string();
-            }
+            let last_modified = sfile_info.last_modified;
 
             if args.flag_json || args.flag_pretty_json {
                 if args.flag_no_infer {
@@ -881,9 +886,7 @@ async fn sniff_main(mut args: Args) -> CliResult<()> {
     let conf = Config::new(&Some(sfile_info.file_to_sniff.clone()))
         .flexible(true)
         .delimiter(args.flag_delimiter);
-    let n_rows = if sfile_info.downloaded_records == 0
-        || sfile_info.retrieved_size <= sfile_info.file_size
-    {
+    let n_rows = if sfile_info.downloaded_records == 0 {
         //if we have the whole file and not just a sample, we can count the number of rows
         match util::count_rows(&conf) {
             Ok(n) => n as usize,
@@ -958,6 +961,13 @@ async fn sniff_main(mut args: Args) -> CliResult<()> {
         fs::copy(sfile_info.file_to_sniff.clone(), save_urlsample)?;
     }
 
+    let quote_char = match args.flag_quote {
+        Some(quote_char) => {
+            qsv_sniffer::metadata::Quote::Some(*quote_char.to_string().as_bytes().first().unwrap())
+        }
+        _ => qsv_sniffer::metadata::Quote::None,
+    };
+
     let sniff_results = if sample_all {
         log::info!("Sniffing ALL rows...");
         if let Some(delimiter) = args.flag_delimiter {
@@ -965,6 +975,7 @@ async fn sniff_main(mut args: Args) -> CliResult<()> {
                 .sample_size(SampleSize::All)
                 .date_preference(dt_preference)
                 .delimiter(delimiter.as_byte())
+                .quote(quote_char)
                 .sniff_reader(rdr.into_inner())
         } else {
             Sniffer::new()
@@ -984,6 +995,7 @@ async fn sniff_main(mut args: Args) -> CliResult<()> {
                 .sample_size(SampleSize::Records(sniff_size))
                 .date_preference(dt_preference)
                 .delimiter(delimiter.as_byte())
+                .quote(quote_char)
                 .sniff_reader(rdr.into_inner())
         } else {
             Sniffer::new()
