@@ -286,10 +286,7 @@ impl Command {
             Command::Select => cmd::select::run(argv),
             Command::Slice => cmd::slice::run(argv),
             Command::Snappy => cmd::snappy::run(argv),
-            Command::Sniff => {
-                let rt = tokio::runtime::Runtime::new().unwrap();
-                rt.block_on(cmd::sniff::run(argv))
-            }
+            Command::Sniff => cmd::sniff::run(argv),
             Command::Sort => cmd::sort::run(argv),
             Command::SortCheck => cmd::sortcheck::run(argv),
             Command::Split => cmd::split::run(argv),
