@@ -728,6 +728,29 @@ fn stats_with_date_inference() {
     assert_eq!(dos2unix(&got2), dos2unix(&expected2).trim_end());
 }
 
+#[test]
+fn stats_with_date_inference_variance_stddev() {
+    let wrk = Workdir::new("stats_with_date_inference_variance_stddev");
+    let test_file = wrk.load_test_file("boston311-100.csv");
+
+    let mut cmd = wrk.command("stats");
+    cmd.arg("--everything")
+        .arg(test_file)
+        .arg("--infer-dates")
+        .arg("--dates-whitelist")
+        .arg("all");
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+
+    wrk.create("in2.csv", got);
+
+    let got2: String = wrk.stdout(&mut cmd);
+    let expected2 =
+        wrk.load_test_resource("boston311-100-everything-date-stats-variance-stddev.csv");
+
+    assert_eq!(dos2unix(&got2), dos2unix(&expected2).trim_end());
+}
+
 #[test]
 fn stats_with_date_type() {
     let wrk = Workdir::new("stats_with_date_type");
